[Libreoffice-commits] core.git: Branch 'libreoffice-4-2' - winaccessibility/source

Julien Nabet serval2412 at yahoo.fr
Thu Jan 30 03:28:37 PST 2014


 winaccessibility/source/UAccCOM/MAccessible.cxx |   18 +++++++++---------
 winaccessibility/source/UAccCOM/MAccessible.h   |    6 +++---
 2 files changed, 12 insertions(+), 12 deletions(-)

New commits:
commit e28dc284596619e2a5000582e4ebd1aa615ddcf8
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Mon Jan 27 23:46:25 2014 +0100

    Typo decendant => descendant in winaccessibility/MAccessible
    
    Change-Id: I2e49ab149b2bbdad623f8694221b6169cdfd2d9a
    Reviewed-on: https://gerrit.libreoffice.org/7706
    Reviewed-by: Caolán McNamara <caolanm at redhat.com>
    Tested-by: Caolán McNamara <caolanm at redhat.com>

diff --git a/winaccessibility/source/UAccCOM/MAccessible.cxx b/winaccessibility/source/UAccCOM/MAccessible.cxx
index 6ed3c4e..50b5a35 100644
--- a/winaccessibility/source/UAccCOM/MAccessible.cxx
+++ b/winaccessibility/source/UAccCOM/MAccessible.cxx
@@ -137,7 +137,7 @@ BSTR IA2_STATES_NAME[] =
     _T("Horizontal"),
     _T("Iconified"),
     _T("Invalid Entry"),
-    _T("Manages Decendents"),
+    _T("Manages Descendants"),
     _T("Modal"),
     _T("Multi Line"),
     _T("Opaque"),
@@ -1467,18 +1467,18 @@ IMAccessible* CMAccessible::GetChildInterface(long dChildID)//for test
 }
 
 /**
 * For List, tree and table,these roles belong to manage_decendant in UNO,
 * need to process specifically when navigate
-* @return  BOOL, if it is decendantmanager, return true.
+* @return  BOOL, if it is descendantmanager, return true.
 */
-BOOL CMAccessible::IsDecendantManage()
+BOOL CMAccessible::IsDescendantManage()
 {
 
     return (m_iRole==ROLE_SYSTEM_LIST)||(m_iRole==ROLE_SYSTEM_OUTLINE)||(m_iRole==ROLE_SYSTEM_TABLE);
 }
 
 /**
-* for decendantmanager circumstance,provide child interface when navigate
+* for descendantmanager circumstance,provide child interface when navigate
 * @param    varCur, the current child.
 * @param    flags, the navigation direction.
 * @return  IMAccessible*, the child of the end up node.
@@ -1557,7 +1557,7 @@ IMAccessible* CMAccessible::GetNavigateChildForDM(VARIANT varCur, short flags)
 
 /**
 * Return first child for parent container, process differently according
 * to whether it is decendant manage
 * @param    varStart, the start child id of this navigation action.
 * @param    pvarEndUpAt, [in,out] the end up child of this navigation action.
 * @return   S_OK if successful and E_FAIL if failure.
@@ -1594,7 +1594,7 @@ HRESULT CMAccessible::GetFirstChild(VARIANT varStart,VARIANT* pvarEndUpAt)
 
 /**
 * Return last child for parent container, process differently according
 * to whether it is decendant manage
 * @param    varStart, the start child id of this navigation action.
 * @param    pvarEndUpAt, [in,out] the end up child of this navigation action.
 * @return   S_OK if successful and E_FAIL if failure.
@@ -1629,7 +1629,7 @@ HRESULT CMAccessible::GetLastChild(VARIANT varStart,VARIANT* pvarEndUpAt)
 }
 
 /**
 * The method GetNextSibling is general, whatever it is decendant manage or not
 * Get the next sibling object.
 * @param    varStart, the start child id of this navigation action.
 * @param    pvarEndUpAt, [in,out] the end up child of this navigation action.
@@ -1665,7 +1665,7 @@ HRESULT CMAccessible::GetNextSibling(VARIANT varStart,VARIANT* pvarEndUpAt)
 }
 
 /**
 *the method GetPreSibling is general, whatever it is decendant manage or not
 * @param    varStart, the start child id of this navigation action.
 * @param    pvarEndUpAt, [in,out] the end up child of this navigation action.
 * @return   S_OK if successful and E_FAIL if failure.
@@ -1467,18 +1467,18 @@ IMAccessible* CMAccessible::GetChildInterface(long dChildID)//for test
 
 /**
-* For List, tree and table,these roles belong to manage_decendant in UNO,
+* For List, tree and table,these roles belong to manage_descendant in UNO,
 * need to process specifically when navigate
@@ -1557,7 +1557,7 @@ IMAccessible* CMAccessible::GetNavigateChildForDM(VARIANT varCur, short flags)
 /**
 * Return first child for parent container, process differently according
-* to whether it is decendant manage
+* to whether it is descendant manage
 * @param    varStart, the start child id of this navigation action.
 * @param    pvarEndUpAt, [in,out] the end up child of this navigation action.
@@ -1594,7 +1594,7 @@ HRESULT CMAccessible::GetFirstChild(VARIANT varStart,VARIANT* pvarEndUpAt)
 /**
 * Return last child for parent container, process differently according
-* to whether it is decendant manage
+* to whether it is descendant manage
 * @param    varStart, the start child id of this navigation action.
 * @param    pvarEndUpAt, [in,out] the end up child of this navigation action.
@@ -1629,7 +1629,7 @@ HRESULT CMAccessible::GetLastChild(VARIANT varStart,VARIANT* pvarEndUpAt)
 
 /**
-* The method GetNextSibling is general, whatever it is decendant manage or not
+* The method GetNextSibling is general, whatever it is descendant manage or not
 * Get the next sibling object.
 * @param    varStart, the start child id of this navigation action.
@@ -1665,7 +1665,7 @@ HRESULT CMAccessible::GetNextSibling(VARIANT varStart,VARIANT* pvarEndUpAt)
 
 /**
-*the method GetPreSibling is general, whatever it is decendant manage or not
+*the method GetPreSibling is general, whatever it is descendant manage or not
 * @param    varStart, the start child id of this navigation action.
 * @param    pvarEndUpAt, [in,out] the end up child of this navigation action.
diff --git a/winaccessibility/source/UAccCOM/MAccessible.h b/winaccessibility/source/UAccCOM/MAccessible.h
index 6c073b5..497f5ca 100644
--- a/winaccessibility/source/UAccCOM/MAccessible.h
+++ b/winaccessibility/source/UAccCOM/MAccessible.h
@@ -197,12 +197,12 @@ private:
 
     // the helper methods in order to implement the above public methods
     IMAccessible* GetChildInterface(long dChildIndex);//notice here the parameter is child index,not child id
-    IMAccessible* GetNavigateChildForDM(VARIANT varCur,short flags);//for decendant manage
+    IMAccessible* GetNavigateChildForDM(VARIANT varCur,short flags);//for descendant manage
     HRESULT GetFirstChild(VARIANT varStart,VARIANT* pvarEndUpAt);//for accNavigate implementation
     HRESULT GetLastChild(VARIANT varStart,VARIANT* pvarEndUpAt);//for accNavigate implementation
     HRESULT GetNextSibling(VARIANT varStart,VARIANT* pvarEndUpAt);//for accNavigate implementation
     HRESULT GetPreSibling(VARIANT varStart,VARIANT* pvarEndUpAt);//for accNavigate implementation
-    BOOL IsDecendantManage();//identify whether the current COM belongs to manage_decendant roles
+    BOOL IsDescendantManage();//identify whether the current COM belongs to manage_descendant roles
 
     // the following private methods are used to implement accSelect method
     HRESULT SelectChild(css::accessibility::XAccessible* pItem);
@@ -222,7 +222,7 @@ private:
 public:
     STDMETHOD(Get_XAccChildID)(/*[out,retval]*/ long* childID);
     // AccObjectManagerAgent is a management object in UNO, here keep its pointer for
     // the implementation of accNavigate when decendant manage happens for List,Tree, or Table
     // AccObjectManagerAgent and the following UNO objects XAccessble,XAccessibleSelection,
     // XAccessibleAction are all used to operate UNO accessiblility information directly when
     // implement some specific MSAA methods,such as accSelection,accNavigate
@@ -222,7 +222,7 @@ private:
     STDMETHOD(Get_XAccChildID)(/*[out,retval]*/ long* childID);
     // AccObjectManagerAgent is a management object in UNO, here keep its pointer for
-    // the implementation of accNavigate when decendant manage happens for List,Tree, or Table
+    // the implementation of accNavigate when descendant manage happens for List,Tree, or Table
     // AccObjectManagerAgent and the following UNO objects XAccessble,XAccessibleSelection,
     // XAccessibleAction are all used to operate UNO accessiblility information directly when


More information about the Libreoffice-commits mailing list